OC.L10N.register(
    "text",
    {
    "File not found" : "Файл олдсонгүй",
    "Translate" : "Орчуулга",
    "Guest" : "Зочин",
    "Saved" : "Хадгалах",
    "Link" : "Холбоос",
    "Undo" : "буцах",
    "Cancel" : "Цуцлах",
    "URL" : "URL",
    "to" : "Дуусах нь",
    "Replace" : "Солих",
    "Edit" : "засварлах",
    "Source code" : "эх үүсвэр талын код",
    "Info" : "Info",
    "Warning" : "Warning",
    "Details" : "Дэлгэрэнгүй"
},
"nplurals=2; plural=(n != 1);");
